netapp_ontap.models.ipv4_interface_and_gateway API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ipv4_interface_and_gateway`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class Ipv4InterfaceAndGatewaySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Ipv4InterfaceAndGateway object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `address: str GET POST PATCH`

    IPv4 address

    Example: 10.10.10.7

  `gateway: str GET POST PATCH`

    The IPv4 address of the default router.

    Example: 10.1.1.1

  `netmask: str GET POST PATCH`

    Input as IPv4 mask (255.255.0.0). Output is always the netmask length.

    Example: 255.255.0.0